// $Id: spotter.hpp,v 1.2 2005/02/25 11:42:48 grosskur Exp $
//
// Copyright (C) 2003 Alan Grosskurth
//
// This file is part of Spatter.
//
// Spatter is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// Spatter is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Spatter; if not, write to the Free Software Foundation,
// Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

#ifndef INCLUDED_SPOTTER_HPP
#define INCLUDED_SPOTTER_HPP

#include <vector>
#include <ltiMatrix.h>
#include <ltiImage.h>

namespace spatter {
    void spotlist_find(const Grid& grid,
                       const lti::image& image,
                       SpotList& spot_list);
}

#endif // INCLUDED_SPOTTER_HPP
